@@ -16,7 +16,7 @@ fn main() -> Result<(), GitMitInstallError> {
             fs::create_dir_all(&hooks)?;
             hooks
         } else {
-            let init_template = PathBuf::from(env!("HOME"))
+            let init_template = PathBuf::from(home_dir())
                 .join(".config")
                 .join("git")
                 .join("init-template");
@@ -41,6 +41,16 @@ fn main() -> Result<(), GitMitInstallError> {
     Ok(())
 }
 
+#[cfg(not(target_os = "windows"))]
+fn home_dir() -> String {
+    env!("HOME").into()
+}
+
+#[cfg(target_os = "windows")]
+fn home_dir() -> String {
+    env!("USERPROFILE").into()
+}
+
 fn install_hook(hook_path: &Path, hook_name: &str) -> Result<(), GitMitInstallError> {
     let binary_path = which::which(format!("mit-{}", hook_name)).unwrap();
     let install_path = hook_path.join(hook_name);
@@ -66,7 +76,21 @@ fn install_hook(hook_path: &Path, hook_name: &str) -> Result<(), GitMitInstallEr
         return Err(GitMitInstallError::ExistingHook);
     }
 
-    std::os::unix::fs::symlink(binary_path, &install_path)?;
+    link(binary_path, install_path)?;
+
+    Ok(())
+}
+
+#[cfg(not(target_os = "windows"))]
+fn link(binary_path: PathBuf, install_path: PathBuf) -> Result<(), GitMitInstallError> {
+    std::os::unix::fs::symlink(binary_path, install_path)?;
+
+    Ok(())
+}
+
+#[cfg(target_os = "windows")]
+fn link(binary_path: PathBuf, install_path: PathBuf) -> Result<(), GitMitInstallError> {
+    std::os::windows::fs::symlink_file(binary_path, install_path)?;
 
     Ok(())
 }
